# Global Project Configuration
project_name: "{{ project_name }}"

{%- if project_type in ['ml', 'dl'] %}
data_urls:
  iris: "https://raw.githubusercontent.com/mwaskom/seaborn-data/master/iris.csv"
  titanic: "https://raw.githubusercontent.com/datasciencedojo/datasets/master/titanic.csv"

datasets:
  # Notebook Name: Kaggle Dataset Handle
  Base_Kaggle: "titanic"
  # Usage: kh.dataset_download(SETTINGS['datasets']['titanic'])
  titanic: "heptapod/titanic"
{%- else %}
# Configuration file for {{ package_name }}
# Add your settings here.
{%- endif %}
